You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [28/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ConstructorAccessorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ConstructorAccessorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ConstructorAccessorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ConstructorAccessorTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.BasicObjectEndpoint;
 import net.jini.jeri.Endpoint;
@@ -82,10 +83,11 @@ import java.util.logging.Level;
  *          to the constructor
  * </pre>
  */
-public class ConstructorAccessorTest extends QATest {
+public class ConstructorAccessorTest extends QATestEnvironment implements Test {
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_ExceptionTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_ExceptionTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_ExceptionTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_ExceptionTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.OutboundRequest;
 import net.jini.jeri.BasicObjectEndpoint;
@@ -87,10 +88,11 @@ import java.io.EOFException;
  *      11) assert EOFException is thrown directly
  * </pre>
  */
-public class ExecuteCall_ExceptionTest extends QATest {
+public class ExecuteCall_ExceptionTest extends QATestEnvironment implements Test {
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_NormalTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_NormalTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_NormalTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ExecuteCall_NormalTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.OutboundRequest;
 import net.jini.jeri.BasicObjectEndpoint;
@@ -83,10 +84,11 @@ import java.rmi.UnmarshalException;
  *     8) assert expectedException is returned
  * </pre>
  */
-public class ExecuteCall_NormalTest extends QATest {
+public class ExecuteCall_NormalTest extends QATestEnvironment implements Test {
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_ExceptionTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_ExceptionTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_ExceptionTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_ExceptionTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.OutboundRequestIterator;
 import net.jini.jeri.BasicObjectEndpoint;
@@ -113,7 +114,7 @@ import java.rmi.ConnectIOException;
  *      16) assert nextException is thrown directly
  * </pre>
  */
-public class NewCall_ExceptionTest extends QATest {
+public class NewCall_ExceptionTest extends QATestEnvironment implements Test {
 
     // test cases
     Throwable[] cases = {
@@ -135,7 +136,8 @@ public class NewCall_ExceptionTest exten
     };
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_NormalTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_NormalTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_NormalTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/NewCall_NormalTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.OutboundRequestIterator;
 import net.jini.jeri.BasicObjectEndpoint;
@@ -79,10 +80,11 @@ import java.util.NoSuchElementException;
  *        throws NoSuchElementException
  * </pre>
  */
-public class NewCall_NormalTest extends QATest {
+public class NewCall_NormalTest extends QATestEnvironment implements Test {
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ObjectMethodsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ObjectMethodsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ObjectMethodsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/basicobjectendpoint/ObjectMethodsTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.basi
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.BasicObjectEndpoint;
 import net.jini.jeri.ObjectEndpoint;
@@ -73,10 +74,11 @@ import java.util.logging.Level;
  *        not .equals to a BasicObjectEndpoint instance
  * </pre>
  */
-public class ObjectMethodsTest extends QATest {
+public class ObjectMethodsTest extends QATestEnvironment implements Test {
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/connection/util/AbstractConnectionTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/connection/util/AbstractConnectionTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/connection/util/AbstractConnectionTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/connection/util/AbstractConnectionTest.java Wed Jan  2 05:20:52 2013
@@ -19,26 +19,28 @@ package com.sun.jini.test.spec.jeri.conn
 
 //test harness related imports
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 
 
 //java.util.logging
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Logger;
 
 /**
  * Abstract class for <code>BasicJeriExporter</code> tests
  */
-public abstract class AbstractConnectionTest implements Test{
+public abstract class AbstractConnectionTest implements LegacyTest{
 
     protected static QAConfig config;
     protected static Logger log = Logger.getLogger(
         "com.sun.jini.test.spec.jeri.connection");
     private int port = 0;
 
-    public void setup(QAConfig config) {
+    public Test construct(QAConfig config) {
         this.config = config;
         port = config.getIntConfigVal(
             "com.sun.jini.test.spec.jeri.connection.listenPort", 9090);
+        return this;
     }
 
     public void tearDown() {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/kerberostrustverifier/util/AbstractTrustVerifierTestKerberos.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/kerberostrustverifier/util/AbstractTrustVerifierTestKerberos.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/kerberostrustverifier/util/AbstractTrustVerifierTestKerberos.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/kerberostrustverifier/util/AbstractTrustVerifierTestKerberos.java Wed Jan  2 05:20:52 2013
@@ -19,12 +19,13 @@ package com.sun.jini.test.spec.jeri.kerb
 
 //harness imports
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 
 //java.util
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Logger;
 
-public abstract class AbstractTrustVerifierTestKerberos implements Test {
+public abstract class AbstractTrustVerifierTestKerberos implements LegacyTest {
 
     protected static QAConfig sysConfig;
     protected static Logger log;
@@ -32,10 +33,11 @@ public abstract class AbstractTrustVerif
         + "jeri.kerberostrustverifier";
 
     //inherit javadoc
-    public void setup(QAConfig config) {
+    public Test construct(QAConfig config) {
         sysConfig = config;
         log = Logger.getLogger(
             "com.sun.jini.test.spec.jeri.kerberostrustverifier");
+        return this;
     }
 
     //inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/mux/util/AbstractMuxTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/mux/util/AbstractMuxTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/mux/util/AbstractMuxTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/mux/util/AbstractMuxTest.java Wed Jan  2 05:20:52 2013
@@ -18,9 +18,10 @@
 package com.sun.jini.test.spec.jeri.mux.util;
 //harness imports
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 
 //jeri imports
+import com.sun.jini.qa.harness.Test;
 import net.jini.config.Configuration;
 import net.jini.config.ConfigurationException;
 import net.jini.jeri.Endpoint;
@@ -37,7 +38,7 @@ import java.util.logging.Logger;
  * Abstract utility class that serves as the base for all
  * Jini ERI Multiplexing Protocol tests.
  */
-public abstract class AbstractMuxTest implements Test {
+public abstract class AbstractMuxTest implements LegacyTest {
 
     protected static QAConfig sysConfig;
     protected static Logger log;
@@ -49,7 +50,7 @@ public abstract class AbstractMuxTest im
     private String host = null;
 
     //inherit javadoc
-    public void setup(QAConfig config) throws UnknownHostException {
+    public Test construct(QAConfig config) throws UnknownHostException {
         sysConfig = config;
         log = Logger.getLogger("com.sun.jini.test.spec.jeri.mux");
         port = config.getIntConfigVal("com.sun.jini.test.spec"
@@ -59,6 +60,7 @@ public abstract class AbstractMuxTest im
         host = InetAddress.getLocalHost().getHostAddress();
         endpoint = new TestEndpoint(port,host);
         se = new TestServerEndpoint(port);
+        return this;
     }
 
     //inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/AccessorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/AccessorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/AccessorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/AccessorTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.prox
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.ProxyTrustILFactory;
 import net.jini.security.proxytrust.ServerProxyTrust;
@@ -74,7 +75,7 @@ import java.util.logging.Level;
  *          ProxyTrust interface is returned
  * </pre>
  */
-public class AccessorTest extends QATest {
+public class AccessorTest extends QATestEnvironment implements Test {
 
     interface FakeRemoteInterface extends Remote {
         public void fakeMethod1() throws RemoteException;
@@ -114,7 +115,8 @@ public class AccessorTest extends QATest
 
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/ConstructorAccessorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/ConstructorAccessorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/ConstructorAccessorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/proxytrustilfactory/ConstructorAccessorTest.java Wed Jan  2 05:20:52 2013
@@ -19,8 +19,9 @@ package com.sun.jini.test.spec.jeri.prox
 
 import java.util.logging.Level;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.jeri.ProxyTrustILFactory;
 import net.jini.export.ExportPermission;
@@ -89,7 +90,7 @@ import java.util.logging.Level;
  *     4) assert IllegalArgumentException is thrown
  * </pre>
  */
-public class ConstructorAccessorTest extends QATest {
+public class ConstructorAccessorTest extends QATestEnvironment implements Test {
 
     // fake ProxyTrustILFactory subclass
     class FakeProxyTrustILFactory extends ProxyTrustILFactory {
@@ -150,7 +151,8 @@ public class ConstructorAccessorTest ext
     };
 
     // inherit javadoc
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        return this;
     }
 
     // inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/ssltrustverifier/util/AbstractTrustVerifierTestSSL.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/ssltrustverifier/util/AbstractTrustVerifierTestSSL.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/ssltrustverifier/util/AbstractTrustVerifierTestSSL.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/ssltrustverifier/util/AbstractTrustVerifierTestSSL.java Wed Jan  2 05:20:52 2013
@@ -19,12 +19,13 @@ package com.sun.jini.test.spec.jeri.sslt
 
 //harness imports
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 
 //java.util
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Logger;
 
-public abstract class AbstractTrustVerifierTestSSL implements Test {
+public abstract class AbstractTrustVerifierTestSSL implements LegacyTest {
 
     protected static QAConfig sysConfig;
     protected static Logger log;
@@ -32,10 +33,11 @@ public abstract class AbstractTrustVerif
         + "jeri.ssltrustverifier";
 
     //inherit javadoc
-    public void setup(QAConfig config) {
+    public Test construct(QAConfig config) {
         sysConfig = config;
         log = Logger.getLogger(
             "com.sun.jini.test.spec.jeri.ssltrustverifier");
+        return this;
     }
 
     //inherit javadoc

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/kerberos/KerberosWrapper.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/kerberos/KerberosWrapper.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/kerberos/KerberosWrapper.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/kerberos/KerberosWrapper.java Wed Jan  2 05:20:52 2013
@@ -20,7 +20,7 @@ package com.sun.jini.test.spec.jeri.tran
 import java.util.logging.Level;
 
 //harness imports
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 import com.sun.jini.qa.harness.TestException;
 
 //utility classes
@@ -46,8 +46,8 @@ public class KerberosWrapper extends Abs
         String wrappedTest = sysConfig
             .getStringConfigVal("jeri.transport.wrappedTest",null);
         Class c = Class.forName(wrappedTest);
-        final Test test = (Test) c.newInstance();
-        test.setup(sysConfig);
+        final LegacyTest test = (LegacyTest) c.newInstance();
+        test.construct(sysConfig);
         Subject.doAs(subject,
             new PrivilegedExceptionAction(){
                 public Object run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/util/AbstractEndpointTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/util/AbstractEndpointTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/util/AbstractEndpointTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/jeri/transport/util/AbstractEndpointTest.java Wed Jan  2 05:20:52 2013
@@ -19,9 +19,10 @@ package com.sun.jini.test.spec.jeri.tran
 
 //harness imports
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 
 //jeri imports
+import com.sun.jini.qa.harness.Test;
 import net.jini.config.Configuration;
 import net.jini.config.ConfigurationException;
 import net.jini.config.ConfigurationFile;
@@ -31,7 +32,7 @@ import net.jini.jeri.ServerEndpoint;
 import java.util.logging.Logger;
 import java.util.logging.Level;
 
-public abstract class AbstractEndpointTest implements Test {
+public abstract class AbstractEndpointTest implements LegacyTest {
 
     protected static QAConfig sysConfig;
     protected static Logger log;
@@ -39,9 +40,10 @@ public abstract class AbstractEndpointTe
         + "jeri.serverendpoint";
     private final static String seEntry = "endpoint";
 
-    public void setup(QAConfig config) {
+    public Test construct(QAConfig config) {
         sysConfig = config;
         log = Logger.getLogger("com.sun.jini.test.spec.jeri.transport");
+        return this;
     }
 
     public void tearDown() {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AbstractBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AbstractBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributes.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.Attribute
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -55,10 +56,11 @@ public class AddAttributes extends GetAt
      *          a new set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         expectedAttrs = addAttrsAndRemoveDups(serviceAttrs,newServiceAttrs);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesDup.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesDup.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesDup.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesDup.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -53,15 +54,16 @@ public class AddAttributesDup extends Ad
      *          method
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Create an array that contains elements from the set of attributes
          * with which the join manager is currently configured, the new
          * set of attributes to be added to the initial set, and duplicates
          * of the elements from the set to be added.
          */
         newServiceAttrs = addAttrsWithDups(serviceAttrs,newServiceAttrs);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class AddAttributesDup
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullElement.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullElement.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullElement.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullElement.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -48,13 +49,13 @@ public class AddAttributesNullElement ex
      *          null element -- to input to the addAttributes method
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         if(newServiceAttrs == null) {
             newServiceAttrs = new Entry[3];
-            for(int i=0;i<nAttributes;i++) {
+            for(int i=0;i<getnAttributes();i++) {
                 newServiceAttrs[i] = new TestServiceIntAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + i);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + i);
             }//end loop
         }//endif
         if(newServiceAttrs.length > 1) {
@@ -62,7 +63,8 @@ public class AddAttributesNullElement ex
         } else {
             newServiceAttrs[0] = null;
         }//endif
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullSet.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullSet.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullSet.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesNullSet.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -44,10 +45,11 @@ public class AddAttributesNullSet extend
      *          the addAttributes method
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         newServiceAttrs = null;
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class AddAttributesNullSet
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesProp.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesProp.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesProp.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesProp.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -58,11 +59,12 @@ public class AddAttributesProp extends R
      *          the new set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         newServiceAttrs = addAttrsWithDups(serviceAttrs,newServiceAttrs);
         expectedAttrs   = addAttrsAndRemoveDups(serviceAttrs,newServiceAttrs);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
@@ -83,7 +85,7 @@ public class AddAttributesProp extends R
 
         logger.log(Level.FINE, "verifying added attributes were "
                                   +"propagated to each lookup service ...");
-        verifyPropagation(expectedAttrs,nSecsJoin);
+        verifyPropagation(expectedAttrs, getnSecsJoin());
         logger.log(Level.FINE, "added attributes successfully propagated to "
                           +"all "+curLookupListSize("AddAttributesProp.run")
                           +" lookup service(s)");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesPropNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesPropNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesPropNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesPropNew.java Wed Jan  2 05:20:52 2013
@@ -50,15 +50,15 @@ public class AddAttributesPropNew extend
         super.run();
 
         /* Stagger-start additional lookup services */
-        logger.log(Level.FINE, "starting "+nAddLookupServices
+        logger.log(Level.FINE, "starting "+getnAddLookupServices()
                           +" additional lookup service(s) ...");
         StaggeredStartThread lookupsThread =
-             new StaggeredStartThread(lookupsStarted.size(),allLookupsToStart);
+             new StaggeredStartThread(getLookupsStarted().size(), getAllLookupsToStart());
         lookupsThread.start();
         try {
             mainListener.clearAllEventInfo();
-            mainListener.setLookupsToDiscover(addLookupsToStart,
-                                             toGroupsArray(addLookupsToStart));
+            mainListener.setLookupsToDiscover(getAddLookupsToStart(),
+                                             toGroupsArray(getAddLookupsToStart()));
             waitForDiscovery(mainListener);
         } finally {
             /* If an exception occurred before the thread finished starting
@@ -75,7 +75,7 @@ public class AddAttributesPropNew extend
         /* Verify attribute propagation to new lookup services */
         logger.log(Level.FINE, "verifying all attributes were "
                           +"propagated to each new lookup service ...");
-        verifyPropagation(expectedAttrs,nSecsJoin);
+        verifyPropagation(expectedAttrs, getnSecsJoin());
         logger.log(Level.FINE, "join manager successfully propagated "
                           +"all attributes to the new lookup service(s)");
     }//end run

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesServiceControlled.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesServiceControlled.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesServiceControlled.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributesServiceControlled.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -51,24 +52,25 @@ public class AddAttributesServiceControl
      *          input to the addAttributes method
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         if(newServiceAttrs == null) {
             newServiceAttrs = new Entry[3];
-            for(int i=0;i<nAttributes;i++) {
+            for(int i=0;i<getnAttributes();i++) {
                 newServiceAttrs[i] = new TestServiceIntAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + i);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + i);
             }//end loop
         }//endif
         /* Replace one of the attributes with a ServiceControlled attribute */
         if(newServiceAttrs.length > 1) {
             newServiceAttrs[1] = new ServiceControlledAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + 1);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + 1);
         } else {
             newServiceAttrs[0] = new ServiceControlledAttr
-                                       (SERVICE_BASE_VALUE + nAttributes);
+                                       (SERVICE_BASE_VALUE + getnAttributes());
         }//endif
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/Equality.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/Equality.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributesNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributesNew.java Wed Jan  2 05:20:52 2013
@@ -41,7 +41,7 @@ public class GetAttributesNew extends Ge
      *   Verifies that each invocation of the <code>getAttributes</code>
      *   method returns a new array whose contents are equal to the contents
      *   of the set of attributes with which the join manager was constructed
-     *   during setup.
+     *   during construct.
      */
     public void run() throws Exception {
         super.run();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetDiscoveryManager.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetDiscoveryManager.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallbackNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallbackNew.java Wed Jan  2 05:20:52 2013
@@ -40,7 +40,7 @@ public class GetJoinSetCallbackNew exten
      *   Verifies that each invocation of method <code>getJoinSet</code>
      *   returns a new array that contains the same lookup services as those
      *   with which the service was registered by the join manager
-     *   created during setup.
+     *   created during construct.
      */
     public void run() throws Exception {
         super.run();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceID.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceID.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceID.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceID.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.lookup.JoinManager;
@@ -52,10 +53,11 @@ public class GetJoinSetServiceID extends
      *          started in the previous step
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         callbackJM = false;//create a "serviceID join manager"
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
 } //end class GetJoinSetServiceID
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceIDNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceIDNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceIDNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetServiceIDNew.java Wed Jan  2 05:20:52 2013
@@ -40,7 +40,7 @@ public class GetJoinSetServiceIDNew exte
      *   Verifies that each invocation of method <code>getJoinSet</code>
      *   returns a new array that contains the same lookup services as those
      *   with which the service was registered by the join manager
-     *   created during setup.
+     *   created during construct.
      */
     public void run() throws Exception {
         super.run();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetLeaseRenewalManager.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetLeaseRenewalManager.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributes.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -46,10 +47,11 @@ public class ModifyAttributes extends Ge
      *          the current attributes to a new set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         expectedAttrs = newServiceAttrs;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesAllToOne.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesAllToOne.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesAllToOne.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesAllToOne.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.joinmanag
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -42,8 +43,8 @@ public class ModifyAttributesAllToOne ex
      *          attribute
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct a template that will match all the current attributes */
         attrTmpls = new Entry[1];
         attrTmpls[0] = new TestServiceIntAttr();//null field matches all
@@ -51,7 +52,8 @@ public class ModifyAttributesAllToOne ex
         expectedAttrs = new Entry[1];
         expectedAttrs[0] = new TestServiceIntAttr
                   (( ((TestServiceIntAttr)newServiceAttrs[0]).val).intValue());
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesAllToOne
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesClassMismatch.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesClassMismatch.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesClassMismatch.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesClassMismatch.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.joinmanag
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -43,8 +44,8 @@ public class ModifyAttributesClassMismat
      *          the set of attribute templates
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct new attributes with different length than templates */
         int chngIndx = newServiceAttrs.length/2;//don't just pick first element
         newAttrs = new Entry[newServiceAttrs.length];
@@ -56,7 +57,8 @@ public class ModifyAttributesClassMismat
                  (( ((TestServiceIntAttr)newServiceAttrs[i]).val).intValue());
             }//endif
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesClassMismatch
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.joinmanag
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -40,14 +41,15 @@ public class ModifyAttributesDeleteAll e
      *          all of the elements of the current attribute set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct the attribute set that indicates deletion is requested */
         newServiceAttrs = new Entry[1];
         newServiceAttrs[0] = null;
         /* Construct attributes to expect after deletion is complete */
         expectedAttrs = new Entry[0];
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesDeleteAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteOne.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteOne.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteOne.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDeleteOne.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import net.jini.core.entry.Entry;
 
 import java.util.ArrayList;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -42,8 +43,8 @@ public class ModifyAttributesDeleteOne e
      *          one of the elements of the current attribute set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct the attribute set that indicates deletion is requested */
         newServiceAttrs = new Entry[1];
         newServiceAttrs[0] = null;
@@ -54,7 +55,8 @@ public class ModifyAttributesDeleteOne e
             tmpList.add(expectedAttrs[i]);
         }//end loop
         expectedAttrs = (Entry[])(tmpList).toArray(new Entry[tmpList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesDeleteOne
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDup.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDup.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDup.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesDup.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.joinmanag
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -42,8 +43,8 @@ public class ModifyAttributesDup extends
      *          intended change to the one element in the current set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct template&attribute set duplicating 1 current attribute */
         Entry tmpEntry0 = attrTmpls[0];
         Entry tmpEntry1 = newServiceAttrs[0];
@@ -55,7 +56,8 @@ public class ModifyAttributesDup extends
             newServiceAttrs[i] = new TestServiceIntAttr
                          (( ((TestServiceIntAttr)tmpEntry1).val).intValue());
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesDup
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesLengthMismatch.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesLengthMismatch.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesLengthMismatch.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesLengthMismatch.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -47,15 +48,16 @@ public class ModifyAttributesLengthMisma
      *          attribute templates
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct new attributes with different length than templates */
         newAttrs = new Entry[newServiceAttrs.length-1];
         for(int i=0;i<newAttrs.length;i++) {
             newAttrs[i] = new TestServiceIntAttr
                  (( ((TestServiceIntAttr)newServiceAttrs[i]).val).intValue());
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesOne.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesOne.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesOne.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesOne.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.joinmanag
 
 import net.jini.core.entry.Entry;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -42,8 +43,8 @@ public class ModifyAttributesOne extends
      *          one of the elements of the current attribute set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         chngIndx = serviceAttrs.length/2;//don't just pick first element
         /* Construct a template that will match 1 of the current attributes */
         attrTmpls = new Entry[1];
@@ -61,7 +62,8 @@ public class ModifyAttributesOne extends
         }//end loop
         expectedAttrs[chngIndx] = new TestServiceIntAttr
                   (( ((TestServiceIntAttr)newServiceAttrs[0]).val).intValue());
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class ModifyAttributesOne
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesProp.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesProp.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesProp.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesProp.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -54,8 +55,8 @@ public class ModifyAttributesProp extend
      *          the current attributes to the new set
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Construct both the template set and the new attribute set to be 1
          * element greater than the initial attribute set with the extra
          * element in the attribute set duplicating one of the other elements
@@ -70,15 +71,16 @@ public class ModifyAttributesProp extend
             attrTmpls[i] = new TestServiceIntAttr
                      (( ((TestServiceIntAttr)serviceAttrs[i]).val).intValue());
             newServiceAttrs[i] = new TestServiceIntAttr
-            (nAttributes+( ((TestServiceIntAttr)attrTmpls[i]).val).intValue());
+            (getnAttributes()+( ((TestServiceIntAttr)attrTmpls[i]).val).intValue());
             expectedAttrs[i] = new TestServiceIntAttr
                   (( ((TestServiceIntAttr)newServiceAttrs[i]).val).intValue());
         }//end loop
         attrTmpls[attrTmpls.length-1] = new TestServiceIntAttr
                             (( ((TestServiceIntAttr)tmpTmpl).val).intValue());
         newServiceAttrs[newServiceAttrs.length-1] = new TestServiceIntAttr
-      (nAttributes+( ((TestServiceIntAttr)newServiceAttrs[0]).val).intValue());
-    }//end setup
+      ( getnAttributes()+( ((TestServiceIntAttr)newServiceAttrs[0]).val).intValue());
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
@@ -103,7 +105,7 @@ public class ModifyAttributesProp extend
 
         logger.log(Level.FINE, "verifying changed attributes were "
                                   +"propagated to each lookup service ...");
-        verifyPropagation(expectedAttrs,nSecsJoin);
+        verifyPropagation(expectedAttrs, getnSecsJoin());
         logger.log(Level.FINE, "changed attributes successfully propagated to "
                           +"all "+curLookupListSize("ModifyAttributesProp.run")
                           +" lookup service(s)");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesPropNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesPropNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesPropNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesPropNew.java Wed Jan  2 05:20:52 2013
@@ -51,15 +51,15 @@ public class ModifyAttributesPropNew ext
         super.run();
 
         /* Stagger-start additional lookup services */
-        logger.log(Level.FINE, "starting "+nAddLookupServices
+        logger.log(Level.FINE, "starting "+getnAddLookupServices()
                           +" additional lookup service(s) ...");
         StaggeredStartThread lookupsThread =
-             new StaggeredStartThread(lookupsStarted.size(),allLookupsToStart);
+             new StaggeredStartThread(getLookupsStarted().size(), getAllLookupsToStart());
         lookupsThread.start();
 	try {
             mainListener.clearAllEventInfo();
-            mainListener.setLookupsToDiscover(addLookupsToStart,
-                                             toGroupsArray(addLookupsToStart));
+            mainListener.setLookupsToDiscover(getAddLookupsToStart(),
+                                             toGroupsArray(getAddLookupsToStart()));
             waitForDiscovery(mainListener);
         } finally {
             /* If an exception occurred before the thread finished starting
@@ -77,7 +77,7 @@ public class ModifyAttributesPropNew ext
         logger.log(Level.FINE, "verifying all attributes were "
                           +"propagated to each new lookup service ...");
         /* Wait for added lookups before beginning verification */
-        verifyPropagation(expectedAttrs,nSecsJoin);
+        verifyPropagation(expectedAttrs, getnSecsJoin());
         logger.log(Level.FINE, "join manager successfully propagated "
                           +"all attributes to the new lookup service(s)");
     }//end run

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesServiceControlled.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesServiceControlled.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesServiceControlled.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributesServiceControlled.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -40,7 +41,7 @@ import net.jini.core.entry.Entry;
  */
 public class ModifyAttributesServiceControlled extends AbstractBaseTest {
 
-    private Entry[] expectedAttrs;
+    private volatile Entry[] expectedAttrs;
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test as follows:
@@ -62,11 +63,11 @@ public class ModifyAttributesServiceCont
      *          manager configured to discover desired lookup services (if any)
      *   </ul>
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         if(serviceAttrs == null) {
             serviceAttrs = new Entry[3];
-            for(int i=0;i<nAttributes;i++) {
+            for(int i=0;i<getnAttributes();i++) {
                 serviceAttrs[i] = new TestServiceIntAttr
                                                      (SERVICE_BASE_VALUE + i);
             }//end loop
@@ -78,32 +79,36 @@ public class ModifyAttributesServiceCont
         } else {
             serviceAttrs[0] = new ServiceControlledAttr(SERVICE_BASE_VALUE);
         }//endif
-        attrTmpls = new Entry[serviceAttrs.length];
-        newServiceAttrs = new Entry[serviceAttrs.length];
-        expectedAttrs = new Entry[serviceAttrs.length];
+        Entry[] attrTmpls = new Entry[serviceAttrs.length];
+        Entry[] newServiceAttrs = new Entry[serviceAttrs.length];
+        Entry[] expectedAttrs = new Entry[serviceAttrs.length];
         for(int i=0;i<serviceAttrs.length;i++) {
             if(serviceAttrs[i] instanceof ServiceControlledAttr) {
                 attrTmpls[i] = new ServiceControlledAttr
                   (( ((ServiceControlledAttr)serviceAttrs[i]).val).intValue());
                 newServiceAttrs[i] = new ServiceControlledAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + i);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + i);
                 expectedAttrs[i] = new ServiceControlledAttr
                 ((((ServiceControlledAttr)newServiceAttrs[i]).val).intValue());
             } else {//default to TestServiceIntAttr
                 attrTmpls[i] = new TestServiceIntAttr
                     (( ((TestServiceIntAttr)serviceAttrs[i]).val).intValue());
                 newServiceAttrs[i] = new TestServiceIntAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + i);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + i);
                 expectedAttrs[i] = new TestServiceIntAttr
                   (( ((TestServiceIntAttr)newServiceAttrs[i]).val).intValue());
             }//endif
         }//end loop
+        this.attrTmpls = attrTmpls;//publish
+        this.newServiceAttrs = newServiceAttrs; //publish.
+        this.expectedAttrs = expectedAttrs;//publish.
         logger.log(Level.FINE, "creating a service ID join manager ...");
         joinMgrSrvcID = new JoinManager(testService,serviceAttrs,serviceID,
                                         getLookupDiscoveryManager(),leaseMgr,
 					sysConfig.getConfiguration());
         joinMgrList.add(joinMgrSrvcID);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AbstractBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AbstractBaseTest.java Wed Jan  2 05:20:52 2013
@@ -28,6 +28,7 @@ import com.sun.jini.test.share.LocatorsU
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryManagement;
 import net.jini.discovery.DiscoveryGroupManagement;
@@ -57,6 +58,8 @@ import java.rmi.RemoteException;
 
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
+import java.util.concurrent.CopyOnWriteArrayList;
 
 import net.jini.config.ConfigurationException;
 
@@ -74,7 +77,7 @@ import net.jini.config.ConfigurationExce
  * in the various test classes that test the methods of the service
  * discovery manager that interact with a filter object.
  * <p>
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -262,23 +265,23 @@ abstract public class AbstractBaseTest e
 
     protected final static int SERVICE_BASE_VALUE = 667;
 
-    protected LookupDiscoveryManager discoveryMgr = null;
-    protected LeaseRenewalManager leaseMgr        = null;
+    protected volatile LookupDiscoveryManager discoveryMgr = null;
+    protected volatile LeaseRenewalManager leaseMgr        = null;
 
-    protected JoinManager joinMgrCallback         = null;
-    protected JoinManager joinMgrSrvcID           = null;
-    protected ArrayList   joinMgrList             = new ArrayList(1);
-
-    protected LookupListener mainListener         = null;
-
-    protected TestService testService    = new TestService(SERVICE_BASE_VALUE);
-    protected ServiceID serviceID        = new ServiceID(0,SERVICE_BASE_VALUE);
-    protected ServiceIDListener callback = null;
-    protected Entry[] serviceAttrs       = null;
-    protected Entry[] newServiceAttrs    = null;
-    protected Entry[] attrTmpls          = null;
-    protected ServiceTemplate template   = null;
-    protected HashMap srvcToNEvents = new HashMap(5);
+    protected volatile JoinManager joinMgrCallback         = null;
+    protected volatile JoinManager joinMgrSrvcID           = null;
+    protected final List<JoinManager> joinMgrList          = new CopyOnWriteArrayList<JoinManager>();
+
+    protected volatile LookupListener mainListener         = null;
+
+    protected final TestService testService    = new TestService(SERVICE_BASE_VALUE);
+    protected final ServiceID serviceID        = new ServiceID(0,SERVICE_BASE_VALUE);
+    protected volatile ServiceIDListener callback = null;
+    protected volatile Entry[] serviceAttrs       = null;
+    protected volatile Entry[] newServiceAttrs    = null;
+    protected volatile Entry[] attrTmpls          = null;
+    protected volatile ServiceTemplate template   = null;
+    protected final HashMap<Object,Integer> srvcToNEvents = new HashMap<Object,Integer>(5); //use synchronized to access.
 
     /** Constructs and returns the LookupDiscoveryManager to use when
      *  constructing a JoinManager (can be overridden by sub-classes)
@@ -286,14 +289,14 @@ abstract public class AbstractBaseTest e
     protected LookupDiscoveryManager getLookupDiscoveryManager()
                                                          throws IOException
     {
-        return getLookupDiscoveryManager(toGroupsArray(allLookupsToStart),
+        return getLookupDiscoveryManager(toGroupsArray(getAllLookupsToStart()),
                                          null);
     }//end getLookupDiscoveryManager
 
     protected LookupDiscoveryManager getLookupDiscoveryManager(QAConfig config)
                                                          throws IOException
     {
-        return getLookupDiscoveryManager(toGroupsArray(allLookupsToStart),
+        return getLookupDiscoveryManager(toGroupsArray(getAllLookupsToStart()),
                                          null, config);
     }//end getLookupDiscoveryManager
 
@@ -384,28 +387,29 @@ abstract public class AbstractBaseTest e
      *    <li> creates a default listener for use with instances of JoinManager
      * </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
-        if(nAttributes > 0) {
-            serviceAttrs = new Entry[nAttributes];
-            attrTmpls    = new Entry[nAttributes];
-            for(int i=0;i<nAttributes;i++) {
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        if(getnAttributes() > 0) {
+            serviceAttrs = new Entry[getnAttributes()];
+            attrTmpls    = new Entry[getnAttributes()];
+            for(int i=0;i<getnAttributes();i++) {
                serviceAttrs[i] = new TestServiceIntAttr
                                                      (SERVICE_BASE_VALUE + i);
                 attrTmpls[i] = new TestServiceIntAttr(SERVICE_BASE_VALUE + i);
             }//end loop
         }//endif
-        if(nAddAttributes > 0) {
-            if(nAttributes <= 0) serviceAttrs = new Entry[0];
-            newServiceAttrs = new Entry[nAddAttributes];
-            for(int i=0;i<nAddAttributes;i++) {
+        if(getnAddAttributes() > 0) {
+            if(getnAttributes() <= 0) serviceAttrs = new Entry[0];
+            newServiceAttrs = new Entry[getnAddAttributes()];
+            for(int i=0;i<getnAddAttributes();i++) {
                 newServiceAttrs[i] = new TestServiceIntAttr
-                                       (SERVICE_BASE_VALUE + nAttributes + i);
+                                       (SERVICE_BASE_VALUE + getnAttributes() + i);
             }//end loop
         }//endif
         template = getServiceTemplate();
         mainListener = new LookupListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test
      */
@@ -465,20 +469,20 @@ abstract public class AbstractBaseTest e
      *  possibility that more events than expected may arrive.
      */
     protected void verifyJoin() throws Exception {
-        logger.log(Level.FINE, "waiting at least "+nSecsJoin
+        logger.log(Level.FINE, "waiting at least "+getnSecsJoin()
                                        +" seconds but no more than "
-                                       +(2*nSecsJoin)+" seconds for join ...");
+                                       +(2*getnSecsJoin())+" seconds for join ...");
         /* Wait at least nSecsJoin */
-        for(int i=0;i<nSecsJoin;i++) {
+        for(int i=0;i<getnSecsJoin();i++) {
             DiscoveryServiceUtil.delayMS(1000);
         }//end loop
         /* Wait no more than another nSecsJoin */
-        ArrayList lusList = getLookupListSnapshot
+        List lusList = getLookupListSnapshot
                                               ("AbstractBaseTest.verifyJoin");
-        ArrayList regList = new ArrayList(lusList.size());
+        List regList = new ArrayList(lusList.size());
         long T0 = System.currentTimeMillis();
         long deltaT = 0;
-        long maxT   = nSecsJoin * 1000; //work in milliseconds
+        long maxT   = getnSecsJoin() * 1000; //work in milliseconds
         while(deltaT < maxT) {
             for(int i=0;i<lusList.size();i++) {
                 ServiceRegistrar reg = (ServiceRegistrar)lusList.get(i);
@@ -518,7 +522,7 @@ abstract public class AbstractBaseTest e
         verifyJoin();
         /* Wait no more than another nSecsJoin for the service ID events */
         int nEventsRcvd = 0;
-        for(int i=0;i<nSecsJoin;i++) {
+        for(int i=0;i<getnSecsJoin();i++) {
             synchronized(srvcToNEvents) {
                 if(srvcToNEvents.size() > 0) {
                     Integer objN = (Integer)srvcToNEvents.get(testService);
@@ -535,7 +539,7 @@ abstract public class AbstractBaseTest e
             DiscoveryServiceUtil.delayMS(1000);
         }//end loop
         if(nEventsRcvd != nEventsExpected) {
-            throw new TestException("join failed -- waited "+nSecsJoin
+            throw new TestException("join failed -- waited "+getnSecsJoin()
                               +" seconds -- "+nEventsExpected
                               +" ServiceID event(s) expected, "+nEventsRcvd
                               +" ServiceID event(s) received");
@@ -545,9 +549,9 @@ abstract public class AbstractBaseTest e
                                         +nEventsRcvd
                                         +" ServiceID event(s) received");
         /* Retrieve and store the service's ID as stored in each lookup */
-        ArrayList lusList = getLookupListSnapshot
+        List lusList = getLookupListSnapshot
                                               ("AbstractBaseTest.verifyJoin");
-        ArrayList srvcIDs = new ArrayList(lusList.size());
+        List srvcIDs = new ArrayList(lusList.size());
         for(int i=0;i<lusList.size();i++) {
             ServiceRegistrar reg = (ServiceRegistrar)lusList.get(i);
 	    /* Verify 1 service registered with lookup service i */
@@ -593,7 +597,7 @@ abstract public class AbstractBaseTest e
     protected void verifyAttrsInJoinMgr(JoinManager joinMgr, Entry[] attrs) 
 	throws Exception
     {
-        ArrayList lusList = getLookupListSnapshot
+        List lusList = getLookupListSnapshot
                                      ("AbstractBaseTest.verifyAttrsInJoinMgr");
         if(lusList.size() > 0) {
             verifyJoin(1);
@@ -645,7 +649,7 @@ abstract public class AbstractBaseTest e
     protected void verifyPropagation(Entry[] attrs, int nSecsWait) 
 	throws Exception
     {
-        ArrayList lusList = getLookupListSnapshot
+        List lusList = getLookupListSnapshot
                                        ("AbstractBaseTest.verifyPropagation");
         if(lusList.size() > 0) {
             if(nSecsWait > 0) {
@@ -658,7 +662,7 @@ abstract public class AbstractBaseTest e
                 DiscoveryServiceUtil.delayMS(1000);
             }//end loop
             /* Wait no more than another nSecsWait */
-            ArrayList regList = new ArrayList(lusList.size());
+            List regList = new ArrayList(lusList.size());
             for(int i=0;i<lusList.size();i++) {
                 regList.add(lusList.get(i));
             }//end loop
@@ -74,7 +77,7 @@ import net.jini.config.ConfigurationExce
  * discovery manager that interact with a filter object.
  * <p>
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/AddAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/Equality.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/Equality.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.lookup.JoinManager;
@@ -51,8 +52,8 @@ public class Equality extends AbstractBa
      *          an instance of a test service and null to all other arguments
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         logger.log(Level.FINE, "creating a callback join manager ...");
         joinMgrCallback = new JoinManager(testService,
 					  serviceAttrs,
@@ -69,12 +70,13 @@ public class Equality extends AbstractBa
 					leaseMgr,
 					sysConfig.getConfiguration());
         joinMgrList.add(joinMgrSrvcID);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
      *   created during the setup process, verifies that the 
      *   <code>equals</code> method returns the appropriate result
      *   depending on the particular instances of <code>JoinManager</code>
      *   being compared.
@@ -69,12 +70,13 @@ public class Equality extends AbstractBa
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
-     *   created during the setup process, verifies that the 
+     *   created during the construct process, verifies that the 
      *   <code>equals</code> method returns the appropriate result
      *   depending on the particular instances of <code>JoinManager</code>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributes.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -53,21 +54,22 @@ public class GetAttributes extends Abstr
      *          the previous step (if any)
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Discover & join lookups just started */
         logger.log(Level.FINE, "creating a service ID join manager ...");
         joinMgrSrvcID = new JoinManager(testService,serviceAttrs,serviceID,
                                         getLookupDiscoveryManager(),leaseMgr,
 					sysConfig.getConfiguration());
         joinMgrList.add(joinMgrSrvcID);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   Verifies that the set of attributes returned by the method
      *   <code>getAttributes</code> is the same as the set of attributes
      *   with which the join manager was constructed during setup.
      */
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
@@ -53,21 +54,22 @@ public class GetAttributes extends Abstr
      *   Verifies that the set of attributes returned by the method
      *   <code>getAttributes</code> is the same as the set of attributes
-     *   with which the join manager was constructed during setup.
+     *   with which the join manager was constructed during construct.
      */
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributesNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetAttributesNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetDiscoveryManager.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetDiscoveryManager.java Wed Jan  2 05:20:52 2013
@@ -21,7 +21,9 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
+import net.jini.core.discovery.LookupLocator;
 
 import net.jini.discovery.DiscoveryManagement;
 
@@ -46,20 +48,21 @@ public class GetDiscoveryManager extends
      *          DiscoveryManagement created above
      *     <li> creates an instance of JoinManager using the version of
      *          the constructor that takes a service ID, inputting 
-     *          an instance of a test service andthe instance of
+     *          an instance of a test service and the instance of
      *          DiscoveryManagement created above
      *   </ul>
      */
-    public void setup(QAConfig config) throws Exception {
-        discoveryMgr = getLookupDiscoveryManager(config);
+    public Test construct(QAConfig config) throws Exception {
+        discoveryMgr = getLookupDiscoveryManager(new String[0], null, config);
         callback = new SrvcIDListener(testService);
-        super.setup(config);
-    }//end setup
+        super.construct(config);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
      *   created during the setup process,
      *   <ul>
      *     <li> retrieves the instance of DiscoveryManagement being
      *          employed by the JoinManager
@@ -46,20 +48,21 @@ public class GetDiscoveryManager extends
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
-     *   created during the setup process,
+     *   created during the construct process,
      *   <ul>
      *     <li> retrieves the instance of DiscoveryManagement being

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallback.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallback.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallback.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallback.java Wed Jan  2 05:20:52 2013
@@ -21,12 +21,14 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.lookup.JoinManager;
 import net.jini.core.lookup.ServiceRegistrar;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -61,8 +63,8 @@ public class GetJoinSetCallback extends 
      *          the lookup services started in the previous step
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Discover & join lookups just started */
         String jmType = ( (callbackJM) ? "callback" : "service ID" );
         logger.log(Level.FINE, "creating a "+jmType+" join manager ...");
@@ -79,28 +81,28 @@ public class GetJoinSetCallback extends 
             nServiceIDEventsExpected = 0;
         }//endif
         joinMgrList.add(jm);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   Verifies that the set of lookup services returned by the method
      *   <code>getJoinSet</code> is the same as the set of lookup services
      *   with which the test service was registered by the join manager
      *   created during setup.
      */
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
 	/* Verify that the lookups were discovered */
 	logger.log(Level.FINE, "verifying the lookup "
 		   +"service(s) are discovered ...");
-	mainListener.setLookupsToDiscover(lookupsStarted,
-					  toGroupsArray(lookupsStarted));
+	mainListener.setLookupsToDiscover(getLookupsStarted(),
+					  toGroupsArray(getLookupsStarted()));
 	waitForDiscovery(mainListener);
 	verifyJoin();
 	joinRegs = jm.getJoinSet();
-	ArrayList lusList = getLookupListSnapshot("GetJoinSetCallback.run");
-	startedRegs = (ServiceRegistrar[])(lusList).toArray
-	    (new ServiceRegistrar[lusList.size()]);
+	List<ServiceRegistrar> lusList = getLookupListSnapshot("GetJoinSetCallback.run");
+	startedRegs = (lusList).toArray(new ServiceRegistrar[lusList.size()]);
 	logger.log(Level.FINE, "comparing the join set to the "
 		   +"set of lookup service(s) started ...");
 	if( !arraysEqual(joinRegs,startedRegs) ) {
@@ -120,7 +122,7 @@ public class GetJoinSetCallback extends 
      *  stored in the <code>joinRegs</code> array, will return a new
      *  array that contains the the same lookup services as those
      *  with which the service was registered by the join manager
      *  created during setup.
      *  
      *  This method will return <code>null</code> if there are no problems.
      *  If the <code>String</code> returned by this method is 
@@ -79,28 +81,28 @@ public class GetJoinSetCallback extends 
      *   <code>getJoinSet</code> is the same as the set of lookup services
      *   with which the test service was registered by the join manager
-     *   created during setup.
+     *   created during construct.
      */
     public void run() throws Exception {
@@ -120,7 +122,7 @@ public class GetJoinSetCallback extends 
      *  array that contains the the same lookup services as those
      *  with which the service was registered by the join manager
-     *  created during setup.
+     *  created during construct.
      *  
      *  This method will return <code>null</code> if there are no problems.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallbackNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetJoinSetCallbackNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetLeaseRenewalManager.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/GetLeaseRenewalManager.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.lease.LeaseRenewalManager;
@@ -50,16 +51,17 @@ public class GetLeaseRenewalManager exte
      *          LeaseRenewalManager created above
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         leaseMgr = new LeaseRenewalManager(sysConfig.getConfiguration());
         callback = new SrvcIDListener(testService);
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
      *   created during the setup process,
      *   <ul>
      *     <li> retrieves the instance of LeaseRenewalManager being
      *          employed by the JoinManager
@@ -50,16 +51,17 @@ public class GetLeaseRenewalManager exte
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
-     *   created during the setup process,
+     *   created during the construct process,
      *   <ul>
      *     <li> retrieves the instance of LeaseRenewalManager being

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/LDMNullPublicGroup.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/LDMNullPublicGroup.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/LDMNullPublicGroup.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/LDMNullPublicGroup.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.spec.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.discovery.DiscoveryManagement;
@@ -31,7 +32,6 @@ import net.jini.lookup.JoinManager;
 
 import net.jini.core.discovery.LookupLocator;
 
-import java.util.ArrayList;
 
 /**
  * This class verifies that when <code>null</code> is input to the
@@ -60,8 +60,8 @@ public class LDMNullPublicGroup extends 
      *          an instance of a test service and null to all other arguments
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         logger.log(Level.FINE, "creating a callback join manager ...");
         joinMgrCallback = new JoinManager(testService,serviceAttrs,callback,
                                           discoveryMgr,leaseMgr,
@@ -72,12 +72,13 @@ public class LDMNullPublicGroup extends 
                                         discoveryMgr,leaseMgr,
 					sysConfig.getConfiguration());
         joinMgrList.add(joinMgrSrvcID);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
      *   created during the setup process,
      *   <ul>
      *     <li> retrieves the instance of DiscoveryManagement being
      *          employed by the JoinManager
@@ -72,12 +72,13 @@ public class LDMNullPublicGroup extends 
      * <p>
      *   For each instance of the <code>JoinManager</code> utility class
-     *   created during the setup process,
+     *   created during the construct process,
      *   <ul>
      *     <li> retrieves the instance of DiscoveryManagement being

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/joinmanager/ModifyAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================